@@ -63,7 +63,7 @@ public class Deducer {
 	static final int MENUMODIFIER = Common.isMac() ? Event.META_MASK : Event.CTRL_MASK;
 	static int menuIndex=3;
 	static String recentActiveData = "";
-	static final String Version= "0.7-5";
+	static final String Version= "0.7-6";
 	public static String guiEnv = ".gui.working.env";
 	public static boolean insideJGR;
 	public static boolean started;
@@ -117,7 +117,7 @@ public class Deducer {
 			DeducerPrefs.initialize();
 			
 			started=true;
-			timedEval(".javaGD.set.class.path(\"org/rosuda/JGR/JavaGD\")");
+			timedEval("JavaGD:::.javaGD.set.class.path(\"org/rosuda/JGR/JavaGD\")");
 			new Thread(new DataRefresher()).start();
 		}catch(Exception e){new ErrorMsg(e);}
 	}
