@@ -84,7 +84,7 @@ public class RDataFrameModel extends ExDefaultTableModel {
 			removeCachedData();
 		rDataName = name;
 		if(rDataName!=null){
-			tempDataName = Deducer.getUniqueName(rDataName + Math.random(),guiEnv);
+			tempDataName = Deducer.getUniqueName(rDataName + (Math.random()+1.0),guiEnv);
 			try {
 				Deducer.timedEval(guiEnv+"$"+tempDataName+"<-"+rDataName+";NULL",false);
 			} catch (Exception e) {
